import bpy  # type: ignore
from pathlib import Path
from .download import download_zip
from pathlib import Path


down_path = Path(__file__).parent
cwd_name = down_path.name
id = cwd_name.lower()
assets_name = cwd_name + "_lib"
assets_name_zh = "花卉绽放动画"

xz_url = "assets_browser" + "/"
download_zip(xz_url + f"{assets_name}.zip", down_path)


def remove_assets_item(context, name):
    asset_libraries = context.preferences.filepaths.asset_libraries
    try:
        asset_libraries.remove(asset_libraries[name])
    except:
        print(f"无法移除 '{name}' 资源库,请检查该名称!")


class ADD_To_Assets_Browser(bpy.types.Operator):
    bl_idname = f"add2_assets_browser.{id}"
    bl_label = f"{cwd_name} - 添加资产"
    bl_description = "添加资源到资产管理器中"
    bl_options = {"REGISTER","UNDO"}
    @classmethod
    def poll(cls, context):
        return True
    def execute(self, context):
        asset_libraries = context.preferences.filepaths.asset_libraries
        names = asset_libraries.keys()
        as_path = str(down_path / assets_name)
        if assets_name_zh not in names :
            asset_libraries.new(name = assets_name_zh,directory=as_path)
            self.report({"INFO"}, f"已添加 '{assets_name_zh}' 到资产库中!")
        elif assets_name_zh in names:
            asset_libraries[assets_name_zh].path = as_path
            self.report({"INFO"}, f"资产库 '{assets_name_zh}' 已存在!")
        return {"FINISHED"}
    
class Remove_From_Assets_Browser(bpy.types.Operator):
    bl_idname = f"remove_from_assets_browser.{id}"
    bl_label = f"{cwd_name} - 移除资产"
    bl_description = "从资产库移除该资产"
    bl_options = {"REGISTER","UNDO"}

    @classmethod
    def poll(cls, context):
        return True
    def execute(self, context):
        remove_assets_item(context,assets_name_zh)
        self.report({"INFO"}, f"已从资产库中移除 '{assets_name_zh}' !")
        return {"FINISHED"}

def add_assets():
    getattr(bpy.ops.add2_assets_browser, id)


class ADD_To_Assets_Browser_Preferences(bpy.types.AddonPreferences):
    bl_idname = __package__

    def draw(self, context):
        layout = self.layout
        row = layout.row()
        row.operator(ADD_To_Assets_Browser.bl_idname, text="添加到资产库中", icon="ADD")
        row.operator(Remove_From_Assets_Browser.bl_idname, text="从资产库中移除", icon="X")


CLASSES = [
    ADD_To_Assets_Browser,
    Remove_From_Assets_Browser,
    ADD_To_Assets_Browser_Preferences,
]
register_class, unregister_class = bpy.utils.register_classes_factory(CLASSES)


def register():
    register_class()
    if not bpy.app.timers.is_registered(add_assets):
        bpy.app.timers.register(add_assets)


def unregister():
    if bpy.app.timers.is_registered(add_assets):
        bpy.app.timers.unregister(add_assets)
    remove_assets_item(bpy.context, assets_name)
    unregister_class()


if __name__ == "__main__":
    register()
